@@ -2,9 +2,16 @@ package WebService::MinFraud::Record::Device;
 
 use Moo;
 
-our $VERSION = '0.003000';
+our $VERSION = '0.004000';
 
 use Types::UUID;
+use WebService::MinFraud::Types qw( Num Str );
+
+has confidence => (
+    is        => 'ro',
+    isa       => Num,
+    predicate => 1,
+);
 
 has id => (
     is        => 'ro',
@@ -12,6 +19,12 @@ has id => (
     predicate => 1,
 );
 
+has last_seen => (
+    is        => 'ro',
+    isa       => Str,
+    predicate => 1,
+);
+
 1;
 
 # ABSTRACT: Contains data for the device associated with a transaction
@@ -26,7 +39,7 @@ WebService::MinFraud::Record::Device - Contains data for the device associated w
 
 =head1 VERSION
 
-version 0.003000
+version 0.004000
 
 =head1 SYNOPSIS
 
@@ -41,7 +54,7 @@ version 0.003000
   my $request  = { device => { ip_address => '24.24.24.24' } };
   my $insights = $client->insights($request);
   my $device   = $insights->device;
-  say $device->id;
+  say 'Device ' . $device->id . ' was last seen ' . $device->last_seen;
 
 =head1 DESCRIPTION
 
@@ -51,6 +64,11 @@ This class contains the data for the device associated with a transaction.
 
 This class provides the following methods:
 
+=head2 confidence
+
+This number represents our confidence that the device_id refers to a unique
+device as opposed to a cluster of similar devices.
+
 =head2 id
 
 A UUID that MaxMind uses for the device associated
@@ -59,13 +77,23 @@ because they are too common (for example, all iPhones of a given model and
 OS release). In these cases, the minFraud service will simply not return a
 UUID for that device.
 
+=head2 last_seen
+
+This is the date and time of the last sighting of the device on the specified
+IP address for your user account. The string is formatted in the ISO 8601
+combined date and time in UTC.
+
 =head1 PREDICATE METHODS
 
 The following predicate methods are available, which return true if the related
 data was present in the response body, false if otherwise:
 
+=head2 has_confidence
+
 =head2 has_id
 
+=head2 has_last_seen
+
 =head1 AUTHOR
 
 Mateu Hunter <mhunter@maxmind.com>
