@@ -2,15 +2,23 @@ package WebService::MinFraud::Role::HasCommonAttributes;
 
 use Moo::Role;
 
-our $VERSION = '0.003000';
+our $VERSION = '0.004000';
 
 use Types::Standard qw( ArrayRef InstanceOf Num Str );
 use Types::UUID;
 use WebService::MinFraud::Record::Warning;
-use WebService::MinFraud::Types qw( NonNegativeInt );
+use WebService::MinFraud::Types qw( NonNegativeInt NonNegativeNum );
 
 requires 'raw';
 
+has funds_remaining => (
+    is        => 'lazy',
+    isa       => NonNegativeNum,
+    init_arg  => undef,
+    builder   => sub { $_[0]->raw->{funds_remaining} },
+    predicate => 1,
+);
+
 has id => (
     is        => 'lazy',
     isa       => Uuid,
@@ -19,6 +27,14 @@ has id => (
     predicate => 1,
 );
 
+has queries_remaining => (
+    is        => 'lazy',
+    isa       => NonNegativeInt,
+    init_arg  => undef,
+    builder   => sub { $_[0]->raw->{queries_remaining} },
+    predicate => 1,
+);
+
 has risk_score => (
     is        => 'lazy',
     isa       => Num,
@@ -27,14 +43,6 @@ has risk_score => (
     predicate => 1,
 );
 
-has credits_remaining => (
-    is        => 'lazy',
-    isa       => NonNegativeInt,
-    init_arg  => undef,
-    builder   => sub { $_[0]->raw->{credits_remaining} },
-    predicate => 1,
-);
-
 has warnings => (
     is  => 'lazy',
     isa => ArrayRef [ InstanceOf ['WebService::MinFraud::Record::Warning'] ],
@@ -60,7 +68,7 @@ WebService::MinFraud::Role::HasCommonAttributes - A role for attributes common t
 
 =head1 VERSION
 
-version 0.003000
+version 0.004000
 
 =head1 AUTHOR
 
