@@ -3,7 +3,7 @@ package WebService::MinFraud::Types;
 use strict;
 use warnings;
 
-our $VERSION = '0.003000';
+our $VERSION = '0.004000';
 
 use GeoIP2::Types qw(
     ArrayRef
@@ -41,6 +41,7 @@ our @EXPORT_OK = qw(
     MaxMindID
     MaxMindLicenseKey
     NonNegativeInt
+    NonNegativeNum
     Num
     Str
     URIObject
@@ -69,6 +70,16 @@ sub IssuerObjectCoercion () {
     );
 }
 
+sub NonNegativeNum () {
+    return quote_sub(
+        q{ GeoIP2::Types::_tc_fail( $_[0], 'NonNegativeNum' )
+               unless defined $_[0]
+               && ! ref $_[0]
+               && $_[0] =~ /^-?\d+(\.\d+)?$/
+               && $_[0] >= 0; }
+    );
+}
+
 1;
 
 # ABSTRACT: Custom types for the MaxMind minFraud service
@@ -83,7 +94,7 @@ WebService::MinFraud::Types - Custom types for the MaxMind minFraud service
 
 =head1 VERSION
 
-version 0.003000
+version 0.004000
 
 =head1 AUTHOR
 
